## This file defines common functions used for data processing.

## folder <- "data/all"
## datafileName <- "benchmark.data"
load_all_data <- function (folder, datafileName) {
  result <- NULL
  folders <- sort(list.files(folder, "[0-9]+"))
  # f <- folders[[6]]
  for (f in folders) {
    v <- strsplit(f, "-")
    data <- load_data_file(paste(folder, f, datafileName, sep = "/"),
                           version = as.numeric(v[[1]][1]),
                           sha     = v[[1]][2])
    result <- rbind(result, data)
  }
  result
}

load_data_file <- function (file, row_names, version = 0, sha = "") {
  if (missing(row_names)) {
    # these row names are hard coded and might not be applicable
    # names like this are generated by ReBench
    row_names <- c("Invocation", "Iteration", "Value", "Unit", "Criterion",
                   "Benchmark", "VM", "Suite", "Extra", "Cores", "InputSize",
                   "Var")
  }
  
  bench <- read.table(file, sep="\t", header=FALSE, col.names=row_names, fill=TRUE)

  # Give Run Ids to the rows, but need to consider different criterions
  # num_criteria <- length(levels(bench$Criterion))
  # run_nums <- seq_len(nrow(bench) / num_criteria)
  # bench$rid <- rep(run_nums, each = num_criteria)
  
  bench$Extra <- factor(bench$Extra)
  bench$Cores <- factor(bench$Cores)
  bench$Suite <- factor(bench$Suite)

  # bench <- mutate(bench, version = version, sha = sha)
  bench
}

load_rds_file <- function (file, version = 0, sha = "") {
  bench <- readRDS(file)

  # Give Run Ids to the rows, but need to consider different criterions
  num_criteria <- length(levels(bench$Criterion))
  run_nums <- seq_len(nrow(bench) / num_criteria)
  bench$rid <- rep(run_nums, each = num_criteria)

  bench <- ddply(bench, ~ Benchmark + VM + Var + Extra + Cores + Suite,
                 here(transform),
                 Iteration = rid - min(rid),
                 version = version,
                 sha = sha)
  bench
}


prepare_vm_names <- function(data) {
  name_map <-     list("Java8U66"              = "Java, 1.8.0_66",
                       "JRubyJ8"               = "Ruby, JRuby 9.0.4.0 + indy", #invokedynamic
                       "MRI22"                 = "Ruby, MRI 2.2",
                       "MRI23"                 = "Ruby, MRI 2.3",
                       "RBX314"                = "Ruby, Rubinius 3.14",
                       "GraalJS"               = "JavaScript, GraalJS",
                       "Node"                  = "JavaScript, Node.js 5.4.0",
                       "SOMns"                 = "SOMns",
                       "SOMns-Enterprise"      = "SOMns GraalVM",
                       "JRubyTruffle"          = "Ruby, JRuby+Truffle, truffle head (basic)",
                       "JRubyTruffleEnterprise" = "Ruby, JRuby+Truffle", # , truffle head
                       
                       "TruffleSOM-graal"      = "TruffleSOM",
                       "TruffleSOM-graal-no-split" = "TruffleSOM.ns",
                       "SOMpp"                 = "SOM++",
                       
                       "AkkaActor"    = "Akka",
                       "JetlangActor" = "Jetlang",
                       "ScalazActor"  = "Scalaz")
  # Rename
  levels(data$VM)  <- map_names(
    levels(data$VM),
    name_map)
  data
}

map_names <- function(old_names, name_map) {
  for (i in 1:length(old_names)) {
    old_name <- old_names[[i]]
    if (!is.null(name_map[[old_name]])) {
      old_names[i] <- name_map[[old_name]]
    }
  }
  old_names
}
